function [mag,ori] = magori(dx,dy)
%
% magori: returns the magnitude and orientation values for Canny edge detector
% On input:
%     dx: gradient in x axis
%     dy: gradient in y axis
% On output:
%     mag: magnitude of edge response at each pixel
%     ori: orientation of edge response at each pixel
% Call:
%     [mag,ori] = magori(dx,dy)
%

[m,n] = size(dx);
mag = zeros(m,n);
ori = zeros(m,n);
mag = sqrt(dx.^2 + dy.^2);
ori = atan2(dy,dx);
